@@ -1,3 +1,38 @@
+function commonNameToLowerFirst(phr) {
+    var str = Ts.subs(0);
+    var pval = Ts.getProp(str, "yleisnimi");
+
+    if (pval == "kyllä") {
+        return Ts.toLowerFirst(phr);
+    }
+    else {
+        return phr;
+    }
+}
+
+Ts.setcall("yleisnimi_pienellä", commonNameToLowerFirst);
+
+// Converts the first character in the string to lower case
+function toLowerFirst(str)
+{
+    return Ts.toLowerFirst(str);
+}
+
+Ts.setcall("pieni_alkukirjain", toLowerFirst);
+
+function conditionalHyphen(str1, str2)
+{
+    if (str1.indexOf(' ') != -1) {
+        return str1 + " -" + str2;
+    }
+    else {
+        return str1 + "-" + str2;
+    }
+}
+
+Ts.setcall("yhdysmerkki", conditionalHyphen);
+
+
 // Set properties of the phrase given by the finalized msgstr in the PO file.
 // The arguments to the call are consecutive pairs of keys and values,
 // as many as needed (i.e. total number of arguments must be even).
@@ -35,6 +70,7 @@ function setMsgstrProps (/*KEY1, VALUE1, ...*/)
     throw Ts.fallback();
 }
 Ts.setcall("aseta", setMsgstrProps);
+
 // NOTE: You can replace "aseta" in the line above with any UTF-8 string,
 // e.g. one in your language so that it blends nicely inside POs.
 
@@ -89,6 +125,7 @@ var call_name_to_prop = {
     "elat" : "elat", // elative case
     "adess" : "adess", // adessive case
     "illat" : "illat", // illative case
+    "hakumuoto" : "hakumuoto",
 //    "lok" : ["lok", "dat"], // locative case (forwarded to dative if missing)
 // commented and left here for the purpose of example
 };
